@@ -23,6 +23,7 @@
  */
 
 #include "webenginepart.h"
+#include "webengineparthtmlmimetypehandler.h"
 
 //#include <QWebHistoryItem>
 #include <QWebEngineSettings>
@@ -35,6 +36,7 @@
 #include "websslinfo.h"
 #include "webhistoryinterface.h"
 #include "webenginewallet.h"
+#include "webengineparterrorschemehandler.h"
 
 #include "ui/searchbar.h"
 #include "ui/passwordbar.h"
@@ -61,6 +63,7 @@
 #include <KConfigGroup>
 #include <KSharedConfig>
 #include <KSslInfoDialog>
+#include <KProtocolManager>
 
 #include <QUrl>
 #include <QFile>
@@ -71,6 +74,7 @@
 #include <QMenu>
 #include <QStatusBar>
 #include "utils.h"
+#include <QWebEngineProfile>
 
 WebEnginePart::WebEnginePart(QWidget *parentWidget, QObject *parent,
                          const QByteArray& cachedHistory, const QStringList& /*args*/)
@@ -84,6 +88,10 @@ WebEnginePart::WebEnginePart(QWidget *parentWidget, QObject *parent,
              m_featurePermissionBar(0),
              m_wallet(Q_NULLPTR)
 {
+    QWebEngineProfile *prof = QWebEngineProfile::defaultProfile();
+    if (!prof->urlSchemeHandler("error")) {
+        prof->installUrlSchemeHandler("error", new WebEnginePartErrorSchemeHandler(prof));
+    }
     KAboutData about = KAboutData(QStringLiteral("webenginepart"),
                                   i18nc("Program Name", "WebEnginePart"),
                                   /*version*/ QStringLiteral("1.3.0"),
@@ -335,6 +343,18 @@ void WebEnginePart::setWallet(WebEngineWallet* wallet)
     }
 }
 
+void WebEnginePart::attemptInstallKIOSchemeHandler(const QUrl& url)
+{
+     if (KProtocolManager::defaultMimetype(url) == "text/html") { // man:, info:, etc.
+        QWebEngineProfile *prof = QWebEngineProfile::defaultProfile();
+        QByteArray scheme = url.scheme().toUtf8();
+        if (!prof->urlSchemeHandler(scheme)) {
+            prof->installUrlSchemeHandler(scheme, new WebEnginePartHtmlMimetypeHandler(prof));
+        }
+    }
+
+}
+
 bool WebEnginePart::openUrl(const QUrl &_u)
 {
     QUrl u (_u);
@@ -373,6 +393,8 @@ bool WebEnginePart::openUrl(const QUrl &_u)
             p->setSslInfo(sslInfo);
         }
     }
+    
+    attemptInstallKIOSchemeHandler(u);
 
     // Set URL in KParts before emitting started; konq plugins rely on that.
     setUrl(u);
